@@ -1,5 +1,4 @@
-## checking os functions
-## thanks to r-tensorflow
+# checking os functions, thanks to r-tensorflow
 
 is_windows <- function() {
     identical(.Platform$OS.type, "windows")
@@ -18,11 +17,10 @@ is_linux <- function() {
 }
 
 is_ubuntu <- function() {
-    # check /etc/lsb-release
     if (is_unix() && file.exists("/etc/lsb-release")) {
-        lsbRelease <- readLines("/etc/lsb-release")
-        any(grepl("Ubuntu", lsbRelease))
+        lsbrelease <- readLines("/etc/lsb-release")
+        any(grepl("Ubuntu", lsbrelease))
     } else {
         FALSE
     }
-}
\ No newline at end of file
+}
