@@ -1,6 +1,6 @@
 Sys.setenv("R_TESTS" = "")
 
-library(testthat)
-library(spacyr)
+library("testthat")
+library("spacyr")
 
 test_check("spacyr")
